%define pybasever 2.6

%define libdir64 %{_prefix}/lib64

Summary: An interpreted, interactive, object-oriented programming language.
Name: python
Version: 2.6.7
Release: 1
License: Python
Group: Development/Languages
URL: http://www.python.org/
Source0: http://www.python.org/ftp/python/%{version}/Python-%{version}.tar.bz2
Source1: http://www.python.org/ftp/python/%{version}/Python-%{version}.tar.bz2.asc
Source2: pyconfig.h
Patch0: %{name}-%{version}-aix.patch
Patch1: %{name}-%{version}-64bit.patch

Provides: python-abi = %{pybasever}
Provides: python(abi) = %{pybasever}
Provides: python2 = %{version}

BuildRequires: readline-devel >= 5.2, openssl-devel >= 0.9.8, gmp-devel
BuildRequires: gdbm-devel, zlib-devel, expat-devel
BuildRequires: tcl tcl-devel tk tk-devel bzip2 pkg-config
BuildRequires: sqlite-devel db4-devel >= 4.7
BuildRequires: make
Requires: readline >= 5.2, openssl >= 0.9.8, gmp
Requires: gdbm, zlib, expat >= 2.0.0
Requires: bzip2 sqlite db4

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root

%description
Python is an interpreted, interactive, object-oriented programming
language often compared to Tcl, Perl, Scheme or Java. Python includes
modules, classes, exceptions, very high level dynamic data types and
dynamic typing. Python supports interfaces to many system calls and
libraries, as well as to various windowing systems (X11, Motif, Tk,
Mac and MFC).

Programmers can write new built-in modules for Python in C or C++.
Python can be used as an extension language for applications that need
a programmable interface. This package contains most of the standard
Python modules, as well as modules for interfacing to the Tix widget
set for Tk and RPM.

Note that documentation for Python is provided in the python-docs
package.


%package libs
Summary: The libraries for python runtime
Group: Applications/System
Requires: %{name} = %{version}-%{release}

%description libs
The python interpreter can be embedded into applications wanting to 
use python as an embedded scripting language.  The python-libs package 
provides the libraries needed for this.


%package devel
Summary: The libraries and header files needed for Python development.
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}
Conflicts: %{name} < %{version}-%{release}

%description devel
The Python programming language's interpreter can be extended with
dynamically loaded extensions and can be embedded in other programs.
This package contains the header files and libraries needed to do
these types of tasks.

Install python-devel if you want to develop Python extensions.  The
python package will also need to be installed.  You'll probably also
want to install the python-docs package, which contains Python
documentation.


%package tools
Summary: A collection of development tools included with Python.
Group: Development/Tools
Requires: %{name} = %{version}-%{release}
Requires: tkinter = %{version}-%{release}

%description tools
The Python package includes several development tools that are used
to build python programs.


%package -n tkinter
Summary: A graphical user interface for the Python scripting language.
Group: Development/Languages
BuildRequires: tcl-devel, tk-devel
Requires: tcl, tk
Requires: %{name} = %{version}-%{release}

%description -n tkinter
The Tkinter (Tk interface) program is an graphical user interface for
the Python scripting language.

You should install the tkinter package if you'd like to use a graphical
user interface for Python programming.


%package test
Summary: The test modules from the main python package
Group: Development/Languages
Requires: %{name} = %{version}-%{release}

%description test

The test modules from the main python package: %{name}
These have been removed to save space, as they are never or almost
never used in production.

You might want to install the python-test package if you're developing python
code that uses more than just unittest and/or test_support.py.


%prep
%setup -q -n Python-%{version}
%patch0
mkdir ../32bit
mv * ../32bit
mv ../32bit .
mkdir 64bit
cd 32bit && tar cf - . | (cd ../64bit ; tar xpf -)
cd ../64bit
%patch1


%build
# setup environment for 32-bit and 64-bit builds
export AR="ar -X32_64"
export NM="nm -X32_64"

# build 64-bit version
export OBJECT_MODE=64
export LDFLAGS="-L%{libdir64} -L%{_libdir}"
cd 64bit
./configure \
    --prefix=%{_prefix} \
    --libdir=%{libdir64} \
    --mandir=%{_mandir} \
    --with-gcc="xlc_r -ma -I/opt/freeware/include -DAIX_GENUINE_CPLUSCPLUS -Wl,-brtl" \
    --with-cxx-main="xlC_r -ma -I/opt/freeware/include -DAIX_GENUINE_CPLUSCPLUS -Wl,-brtl" \
    --enable-shared \
    --disable-ipv6 \
    --with-threads \
    --with-system-ffi \
    OPT="-O"

gmake %{?_smp_mflags} lib%{name}%{pybasever}.a

CreateExportList -X64 lib%{name}.exp lib%{name}%{pybasever}.a
xlc_r -q64 -qmkshrobj lib%{name}%{pybasever}.a -o lib%{name}%{pybasever}.so -bE:lib%{name}.exp -lm
rm -f lib%{name}.exp lib%{name}%{pybasever}.a
${AR} -rv lib%{name}%{pybasever}.a lib%{name}%{pybasever}.so

gmake %{?_smp_mflags}

# build 32-bit version
export OBJECT_MODE=32
export LDFLAGS="-L%{_libdir}"
cd ../32bit

./configure \
    --prefix=%{_prefix} \
    --mandir=%{_mandir} \
    --with-gcc="xlc_r -ma -I/opt/freeware/include -DAIX_GENUINE_CPLUSCPLUS -Wl,-brtl" \
    --with-cxx-main="xlC_r -ma -I/opt/freeware/include -DAIX_GENUINE_CPLUSCPLUS -Wl,-brtl" \
    --enable-shared \
    --disable-ipv6 \
    --with-threads \
    --with-system-ffi \
    OPT="-O"

gmake %{?_smp_mflags} lib%{name}%{pybasever}.a

CreateExportList -X32 lib%{name}.exp lib%{name}%{pybasever}.a
xlc_r -q32 -qmkshrobj lib%{name}%{pybasever}.a -o lib%{name}%{pybasever}.so -bE:lib%{name}.exp -lm
rm -f lib%{name}.exp lib%{name}%{pybasever}.a
${AR} -rv lib%{name}%{pybasever}.a lib%{name}%{pybasever}.so

gmake %{?_smp_mflags}


%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}

cd 64bit
export OBJECT_MODE=64
gmake DESTDIR=${RPM_BUILD_ROOT} install

cp ${RPM_BUILD_ROOT}%{_includedir}/%{name}%{pybasever}/pyconfig.h ${RPM_BUILD_ROOT}%{_includedir}/%{name}%{pybasever}/pyconfig-ppc64.h 

(
  cd ${RPM_BUILD_ROOT}%{_bindir}

  for f in * ; do
    mv ${f} ${f}_64
  done
  mv smtpd.py_64 smtpd_64.py
  mv %{name}%{pybasever}-config_64 %{name}%{pybasever}_64-config

  rm -f %{name}-config_64
  ln -sf %{name}%{pybasever}_64-config %{name}_64-config

  for f in 2to3_64 idle_64 pydoc_64 python2.6_64-config smtpd_64.py ; do
    cat ${f} | \
      sed 's|\/opt\/freeware\/bin\/python2.6|\/opt\/freeware\/bin\/python2.6_64|' \
      > tmpfile.tmp
    mv -f tmpfile.tmp ${f}
  done
  rm -f tmpfile.tmp
)

cd ../32bit
export OBJECT_MODE=32
gmake DESTDIR=${RPM_BUILD_ROOT} install

cp ${RPM_BUILD_ROOT}%{_includedir}/%{name}%{pybasever}/pyconfig.h ${RPM_BUILD_ROOT}%{_includedir}/%{name}%{pybasever}/pyconfig-ppc32.h 
cp %{SOURCE2} ${RPM_BUILD_ROOT}%{_includedir}/%{name}%{pybasever}/pyconfig.h 

/usr/bin/strip -X32_64 ${RPM_BUILD_ROOT}%{_bindir}/* || :

(
  cd ${RPM_BUILD_ROOT}
  for dir in bin include lib lib64
  do
    mkdir -p usr/$dir
    cd usr/$dir
    ln -sf ../..%{_prefix}/$dir/* .
    cd -
  done
)

cd ..

find ${RPM_BUILD_ROOT}%{_libdir}/%{name}%{pybasever}/lib-dynload -type d | sed "s|${RPM_BUILD_ROOT}|%dir |" > dynfiles
find ${RPM_BUILD_ROOT}%{libdir64}/%{name}%{pybasever}/lib-dynload -type d | sed "s|${RPM_BUILD_ROOT}|%dir |" >> dynfiles
find ${RPM_BUILD_ROOT}%{_libdir}/%{name}%{pybasever}/lib-dynload -type f | \
  grep -v "_tkinter.so$" | \
  grep -v "_ctypes_test.so$" | \
  grep -v "_testcapi.so$" | \
  sed "s|${RPM_BUILD_ROOT}||" >> dynfiles
find ${RPM_BUILD_ROOT}%{libdir64}/%{name}%{pybasever}/lib-dynload -type f | \
  grep -v "_tkinter.so$" | \
  grep -v "_ctypes_test.so$" | \
  grep -v "_testcapi.so$" | \
  sed "s|${RPM_BUILD_ROOT}||" >> dynfiles

ln -sf ../../lib%{name}%{pybasever}.a ${RPM_BUILD_ROOT}%{_libdir}/%{name}%{pybasever}/config/lib%{name}%{pybasever}.a
ln -sf ../../lib%{name}%{pybasever}.a ${RPM_BUILD_ROOT}%{libdir64}/%{name}%{pybasever}/config/lib%{name}%{pybasever}.a


%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}


%files -f dynfiles
%defattr(-,root,system)
%doc 32bit/LICENSE 32bit/README
%{_bindir}/pydoc*
%{_bindir}/python*
%{_mandir}/man?/*
%dir %{_libdir}/%{name}%{pybasever}
%dir %{libdir64}/%{name}%{pybasever}
%{_libdir}/%{name}%{pybasever}/LICENSE.txt
%{libdir64}/%{name}%{pybasever}/LICENSE.txt
%dir %{_libdir}/%{name}%{pybasever}/site-packages
%dir %{libdir64}/%{name}%{pybasever}/site-packages
%{_libdir}/%{name}%{pybasever}/site-packages/README
%{libdir64}/%{name}%{pybasever}/site-packages/README
%{_libdir}/%{name}%{pybasever}/*.py*
%{libdir64}/%{name}%{pybasever}/*.py*
%{_libdir}/%{name}%{pybasever}/*.doc
%{libdir64}/%{name}%{pybasever}/*.doc
%dir %{_libdir}/%{name}%{pybasever}/bsddb
%dir %{libdir64}/%{name}%{pybasever}/bsddb
%{_libdir}/%{name}%{pybasever}/bsddb/*.py*
%{libdir64}/%{name}%{pybasever}/bsddb/*.py*
%{_libdir}/%{name}%{pybasever}/compiler
%{libdir64}/%{name}%{pybasever}/compiler
%dir %{_libdir}/%{name}%{pybasever}/ctypes
%dir %{libdir64}/%{name}%{pybasever}/ctypes
%{_libdir}/%{name}%{pybasever}/ctypes/*.py*
%{libdir64}/%{name}%{pybasever}/ctypes/*.py*
%{_libdir}/%{name}%{pybasever}/ctypes/macholib
%{libdir64}/%{name}%{pybasever}/ctypes/macholib
%{_libdir}/%{name}%{pybasever}/curses
%{libdir64}/%{name}%{pybasever}/curses
%dir %{_libdir}/%{name}%{pybasever}/distutils
%dir %{libdir64}/%{name}%{pybasever}/distutils
%{_libdir}/%{name}%{pybasever}/distutils/*.py*
%{libdir64}/%{name}%{pybasever}/distutils/*.py*
%{_libdir}/%{name}%{pybasever}/distutils/README
%{libdir64}/%{name}%{pybasever}/distutils/README
%{_libdir}/%{name}%{pybasever}/distutils/command
%{libdir64}/%{name}%{pybasever}/distutils/command
%dir %{_libdir}/%{name}%{pybasever}/email
%dir %{libdir64}/%{name}%{pybasever}/email
%{_libdir}/%{name}%{pybasever}/email/*.py*
%{libdir64}/%{name}%{pybasever}/email/*.py*
%{_libdir}/%{name}%{pybasever}/email/mime
%{libdir64}/%{name}%{pybasever}/email/mime
%{_libdir}/%{name}%{pybasever}/encodings
%{libdir64}/%{name}%{pybasever}/encodings
%{_libdir}/%{name}%{pybasever}/hotshot
%{libdir64}/%{name}%{pybasever}/hotshot
%{_libdir}/%{name}%{pybasever}/idlelib
%{libdir64}/%{name}%{pybasever}/idlelib
%dir %{_libdir}/%{name}%{pybasever}/json
%dir %{libdir64}/%{name}%{pybasever}/json
%{_libdir}/%{name}%{pybasever}/json/*.py*
%{libdir64}/%{name}%{pybasever}/json/*.py*
%dir %{_libdir}/%{name}%{pybasever}/lib2to3
%dir %{libdir64}/%{name}%{pybasever}/lib2to3
%{_libdir}/%{name}%{pybasever}/lib2to3/*.py*
%{libdir64}/%{name}%{pybasever}/lib2to3/*.py*
%{_libdir}/%{name}%{pybasever}/lib2to3/Grammar*
%{libdir64}/%{name}%{pybasever}/lib2to3/Grammar*
%{_libdir}/%{name}%{pybasever}/lib2to3/Pattern*
%{libdir64}/%{name}%{pybasever}/lib2to3/Pattern*
%{_libdir}/%{name}%{pybasever}/lib2to3/fixes
%{libdir64}/%{name}%{pybasever}/lib2to3/fixes
%{_libdir}/%{name}%{pybasever}/lib2to3/pgen2
%{libdir64}/%{name}%{pybasever}/lib2to3/pgen2
%{_libdir}/%{name}%{pybasever}/logging
%{libdir64}/%{name}%{pybasever}/logging
%{_libdir}/%{name}%{pybasever}/multiprocessing
%{libdir64}/%{name}%{pybasever}/multiprocessing
%{_libdir}/%{name}%{pybasever}/plat-aix5
%{libdir64}/%{name}%{pybasever}/plat-aix5
%dir %{_libdir}/%{name}%{pybasever}/sqlite3
%dir %{libdir64}/%{name}%{pybasever}/sqlite3
%{_libdir}/%{name}%{pybasever}/sqlite3/*.py*
%{libdir64}/%{name}%{pybasever}/sqlite3/*.py*
%{_libdir}/%{name}%{pybasever}/wsgiref*
%{libdir64}/%{name}%{pybasever}/wsgiref*
%{_libdir}/%{name}%{pybasever}/xml
%{libdir64}/%{name}%{pybasever}/xml
/usr/bin/pydoc*
/usr/bin/python*


%files libs
%defattr(-,root,system)
%doc 32bit/LICENSE 32bit/README
%{_libdir}/lib%{name}%{pybasever}.a
%{libdir64}/lib%{name}%{pybasever}.a
/usr/lib/lib%{name}%{pybasever}.a
/usr/lib64/lib%{name}%{pybasever}.a


%files devel
%defattr(-,root,system)
%doc 32bit/Misc/README.valgrind 32bit/Misc/valgrind-python.supp
%doc 32bit/Misc/gdbinit
%{_includedir}/*
%{_libdir}/%{name}%{pybasever}/config
%{libdir64}/%{name}%{pybasever}/config
/usr/include/*


%files tools
%defattr(-,root,system,-)
%{_bindir}/2to3*
%{_bindir}/idle*
%{_bindir}/smtpd*.py*
/usr/bin/2to3*
/usr/bin/idle*
/usr/bin/smtpd*.py*


%files -n tkinter
%defattr(-,root,system,-)
%{_libdir}/%{name}%{pybasever}/lib-tk
%{libdir64}/%{name}%{pybasever}/lib-tk
%{_libdir}/%{name}%{pybasever}/lib-dynload/_tkinter.so
%{libdir64}/%{name}%{pybasever}/lib-dynload/_tkinter.so


%files test
%defattr(-,root,system)
%{_libdir}/%{name}%{pybasever}/bsddb/test
%{libdir64}/%{name}%{pybasever}/bsddb/test
%{_libdir}/%{name}%{pybasever}/ctypes/test
%{libdir64}/%{name}%{pybasever}/ctypes/test
%{_libdir}/%{name}%{pybasever}/distutils/tests
%{libdir64}/%{name}%{pybasever}/distutils/tests
%{_libdir}/%{name}%{pybasever}/email/test
%{libdir64}/%{name}%{pybasever}/email/test
%{_libdir}/%{name}%{pybasever}/lib2to3/tests
%{libdir64}/%{name}%{pybasever}/lib2to3/tests
%{_libdir}/%{name}%{pybasever}/json/tests
%{libdir64}/%{name}%{pybasever}/json/tests
%{_libdir}/%{name}%{pybasever}/sqlite3/test
%{libdir64}/%{name}%{pybasever}/sqlite3/test
%{_libdir}/%{name}%{pybasever}/test
%{libdir64}/%{name}%{pybasever}/test
%{_libdir}/%{name}%{pybasever}/lib-dynload/_ctypes_test.so
%{libdir64}/%{name}%{pybasever}/lib-dynload/_ctypes_test.so
%{_libdir}/%{name}%{pybasever}/lib-dynload/_testcapi.so
%{libdir64}/%{name}%{pybasever}/lib-dynload/_testcapi.so


%changelog
* Sat Nov 19 2011 Michael Perzl <michael@perzl.org> - 2.6.7-1
- updated to version 2.6.7

* Wed Aug 26 2009 Michael Perzl <michael@perzl.org> - 2.6.2-1
- first version for AIX V5.1 and higher
